@@ -3,7 +3,7 @@ package WiringPi::API;
 use strict;
 use warnings;
 
-our $VERSION = '2.36.1';
+our $VERSION = '2.36.2';
 
 require XSLoader;
 XSLoader::load('WiringPi::API', $VERSION);
@@ -24,7 +24,8 @@ my @wpi_c_functions = qw(
     softPwmCreate       softPwmWrite        softPwmStop
     sr595Setup          bmp180Setup         bmp180Pressure
     bmp180Temp          analogRead          analogWrite
-    physPinToWpi
+    physPinToWpi        wiringPiVersion     ads1115Setup
+    pseudoPinsSetup
 );
 
 my @wpi_perl_functions = qw(
@@ -37,6 +38,7 @@ my @wpi_perl_functions = qw(
     set_interrupt   soft_pwm_create soft_pwm_write      soft_pwm_stop
     shift_reg_setup bmp180_setup    bmp180_pressure     bmp180_temp
     analog_read     analog_write    pin_mode            phys_to_wpi
+    ads1115_setup
 );
 
 our @EXPORT_OK;
@@ -98,6 +100,9 @@ sub setup_gpio {
 sub pin_mode {
     shift if @_ == 3;
     my ($pin, $mode) = @_;
+    if (! grep {$mode == $_} qw(0 1 2 3)){
+        die "pin_mode() requires either 0, 1, 2 or 3 as a param";
+    }
     pinMode($pin, $mode);
 }
 sub pull_up_down {
@@ -220,6 +225,15 @@ sub lcd_puts {
     lcdPuts($fd, $string);
 }
 
+# ads1115 functions
+
+sub ads1115_setup {
+    shift if @_ == 3;
+    my ($pin_base, $addr) = @_;
+
+    return ads1115Setup($pin_base, $addr);
+}
+
 # shift register functions
 
 sub shift_reg_setup {
@@ -245,8 +259,8 @@ sub shift_reg_setup {
 # bmp180 pressure sensor functions
 
 sub bmp180_setup {
-    my ($self, $base) = @_;
-    shift if @_ == 3;
+    shift if @_ == 2;
+    my $base = shift;
 
     if (! defined $base || $base !~ /^\d+$/){
         die "bmp180 setup parametermust be an integer\n";
@@ -362,11 +376,13 @@ wrapper for C<wiringPiISR()> in order to make it functional here.
 
 Exported with the C<:perl> tag.
 
-Perl wrapper functions for the XS functions.
+Perl wrapper functions for the XS functions. Not all of these are direct
+wrappers; several have additional/modified functionality than the wrapped
+versions, but are still 100% compatible.
 
     setup           setup_sys       setup_phys          setup_gpio 
     pull_up_down    read_pin        write_pin           pwm_write
-    get_alt         board_rev       wpi_to_gpio         phys_to_gpio
+    get_alt         gpio_layout     wpi_to_gpio         phys_to_gpio
     pwm_set_range   lcd_init        lcd_home            lcd_clear
     lcd_display     lcd_cursor      lcd_cursor_blink    lcd_send_cmd
     lcd_position    lcd_char_def    lcd_put_char        lcd_puts
@@ -388,6 +404,40 @@ See L<EXPORT_OK>
 
 Exports all available exportable functions.
 
+=head1 FUNCTION TOC
+
+=head2 CORE
+
+See L</CORE FUNCTIONS>.
+
+=head2 BOARD
+
+See L</BOARD FUNCTIONS>.
+
+=head2 LCD
+
+See L</LCD FUNCTIONS>.
+
+=head2 SOFTWARE PWM
+
+See L</SOFT PWM FUNCTIONS>.
+
+=head2 INTERRUPT
+
+See L</INTERRUPT FUNCTIONS>.
+
+=head2 ANALOG TO DIGITAL CONVERTER
+
+See L</ADC FUNCTIONS>.
+
+=head2 SHIFT REGISTER
+
+See L</SHIFT REGISTER FUNCTIONS>.
+
+=head2 BAROMETRIC SENSOR
+
+See L</BMP180 PRESSURE SENSOR FUNCTIONS>.
+
 =head1 CORE FUNCTIONS
 
 =head2 new()
@@ -403,33 +453,10 @@ Maps to C<int wiringPiSetup()>
 
 Sets the pin number mapping scheme to C<wiringPi>.
 
-This setup routine requires you to run your script as the C<root> user.
-
-Each setup function has benefits and drawbacks. Please refer to the
-L<wiringPi setup functions|http://wiringpi.com/reference/setup> for details.
-
 See L<pinout.xyz|https://pinout.xyz/pinout/wiringpi> for a pin number
 conversion chart, or on the command line, run C<gpio readall>.
 
-Note that only one of the C<setup*()> methods can be called per program run.
-
-=head2 setup_sys()
-
-Maps to C<int wiringPiSetupSys()>
-
-Sets the pin numbering scheme to C<GPIO>.
-
-This setup routine does NOT require running as root, but you have to manually
-export the pins yourself with the C<gpio> command line utility prior to using
-the pins.
-
-=head2 setup_phys()
-
-Maps to C<int wiringPiSetupPhys()>
-
-Sets the pin mapping to use the physical pin position number on the board.
-
-This setup routine requires you to run your script as the C<root> user.
+Note that only one of the C<setup*()> methods should be called per program run.
 
 =head2 setup_gpio()
 
@@ -437,7 +464,26 @@ Maps to C<int wiringPiSetupGpio()>
 
 Sets the pin numbering scheme to C<GPIO>.
 
-This setup routine requires you to run your script as the C<root> user.
+Personally, this is the setup routine that I always use, due to the GPIO numbers
+physically printed right on the Pi board.
+
+=head2 setup_phys()
+
+Maps to C<int wiringPiSetupPhys()>
+
+Sets the pin mapping to use the physical pin position number on the board.
+
+=head2 setup_sys()
+
+Maps to C<int wiringPiSetupSys()>
+
+DEPRECATED.
+
+This function is here for legacy purposes only, to provide non-root user access
+to the GPIO. It required exporting the pins manually before use. wiringPi now
+uses C</dev/gpiomem> by default, which does not require root level access.
+
+Sets the pin numbering scheme to C<GPIO>.
 
 =head2 pin_mode($pin, $mode)
 
@@ -568,11 +614,11 @@ C<setup*()> routine you used.
 
 =head1 BOARD FUNCTIONS
 
-=head2 board_rev()
+=head2 gpio_layout()
 
 Maps to C<int piGpioLayout()>
 
-Returns the Raspberry Pi board's revision.
+Returns the Raspberry Pi board's GPIO layout (ie. the board revision).
 
 =head2 wpi_to_gpio($pin_num)
 
@@ -894,6 +940,44 @@ Mandatory: The string name of a subroutine previously written in your user code
 that will be called when the interrupt is triggered. This is your interrupt
 handler.
 
+=head1 ADC FUNCTIONS
+
+Analog to digital converters (ADC) allow you to read analog data on the
+Raspberry Pi, as the Pi doesn't have any analog input pins.
+
+This section is broken down by type/model.
+
+=head2 ADS1115 MODEL
+
+=head3 ads1115Setup($pin_base, $addr)
+
+The ADS1115 is a four channel, 16-bit wide ADC.
+
+Parameters:
+
+    $pin_base
+
+Mandatory: Signed integer, higher than that of all GPIO pins. This is the base
+number we'll use to access the pseudo pins on the ADC. Example: If C<400> is
+sent in, ADC pin C<A0> (or C<0>) will be pin 400, and C<AD3> (the fourth analog
+pin) will be 403.
+
+Parameters:
+
+    $addr
+
+Mandatory: Signed integer. This parameter depends on how you have the C<ADDR>
+pin on the ADC connected to the Pi. Below is a chart showing if the C<ADDR> pin
+is connected to the Pi C<Pin>, you'll get the address. You can also use
+C<i2cdetect -y 1> to find out your ADC address.
+
+    Pin     Address
+    ---------------
+    Gnd     0x48
+    VDD     0x49
+    SDA     0x4A
+    SCL     0x4B
+
 =head1 SHIFT REGISTER FUNCTIONS
 
 Shift registers allow you to add extra output pins by multiplexing a small
@@ -993,6 +1077,68 @@ Return: A floating point number that represents the air pressure in kPa.
 NOTE: To get the raw sensor pressure, call the C function 
 C<bmp180Pressure($pin)> directly.
 
+=head1 DEVELOPER FUNCTIONS
+
+These functions are under testing, or don't potentially have a use to the end
+user. They may be risky to use, so use at your own risk.
+
+The functions in this section do not have a Perl wrapper equivalent.
+
+=head2 pseudoPinsSetup(int pinBase)
+
+This function allocates shared memory for the pseudo pins used to communicate
+with devices that are beyond the reach of the Pi's GPIO (eg: shift registers,
+ADCs etc).
+
+Parameters:
+
+    pinBase
+
+Mandatory: Integer, larger than the highest GPIO pin number. Eg: C<500> will be
+the base for the analog pins on an ADS1115 ADC. Pin C<A0> would be C<500>, and
+ADC pin C<A3> would be C<503>.
+
+=head2 pinModeAlt(int pin, int mode)
+
+Undocumented function that allows any pin to be set to any mode.
+
+Parameters:
+
+    pin
+
+Mandatory: Signed integer, any valid GPIO pin number.
+
+    mode
+
+Mandatory: Signed integer, any valid wiringPi pin mode.
+
+=head2 digitalWriteByte(const int value)
+
+Writes an 8-bit byte to the first eight GPIO pins.
+
+Parameters:
+
+    value
+
+Mandatory: Unsigned int, the byte value you want to send in.
+
+Return: void
+
+=head2 digitalWriteByte2(const int value)
+
+Same as L</digitalWriteByte(const int value)>, but writes to the second group
+of eight GPIO pins.
+
+=head2 digitalReadByte()
+
+Reads an 8-bit byte from the first eight GPIO pins on the Pi.
+
+Takes no parameters, returns the byte value as an unsigned int.
+
+=head2 digitalReadByte2()
+
+Same as L</digitalReadByte>, but reads from the second group of eight GPIO pins.
+
 head1 AUTHOR
 
 Steve Bertrand, E<lt>steveb@cpan.orgE<gt>
